@@ -32,12 +32,9 @@
 #include <KMime/HeaderParsing>
 
 #include <KIdentityManagement/Identity>
-#include <KIdentityManagement/IdentityManager>
-
 #include <KCodecs/KEmailAddress>
 
 #include <KEMailSettings>
-#include <KSystemTimeZone>
 
 using namespace CalendarSupport;
 
@@ -62,7 +59,8 @@ public:
     QDateTime mDayBegins;
 };
 
-KCalPrefs::KCalPrefs() : KCalPrefsBase(), d(new Private())
+KCalPrefs::KCalPrefs() : KCalPrefsBase()
+    , d(new Private())
 {
 }
 
@@ -102,11 +100,6 @@ void KCalPrefs::usrSetDefaults()
     KConfigSkeleton::usrSetDefaults();
 }
 
-KDateTime::Spec KCalPrefs::timeSpec()
-{
-    return KSystemTimeZones::local();
-}
-
 Akonadi::Collection::Id KCalPrefs::defaultCalendarId() const
 {
     return d->mDefaultCalendarId;
@@ -142,8 +135,8 @@ void KCalPrefs::usrRead()
 #if 0
     config()->setGroup("FreeBusy");
     if (mRememberRetrievePw) {
-        d->mRetrievePassword =
-            KStringHandler::obscure(config()->readEntry("Retrieve Server Password"));
+        d->mRetrievePassword
+            = KStringHandler::obscure(config()->readEntry("Retrieve Server Password"));
     }
 #endif
 
@@ -272,7 +265,7 @@ bool KCalPrefs::thatIsMe(const QString &_email)
     CalendarSupport::IdentityManager::ConstIterator it;
     CalendarSupport::IdentityManager::ConstIterator endId(CalendarSupport::identityManager()->end());
     for (it = CalendarSupport::identityManager()->begin();
-            it != endId; ++it) {
+         it != endId; ++it) {
         if ((*it).matchesEmailAddress(email)) {
             return true;
         }
@@ -309,7 +302,7 @@ QColor KCalPrefs::categoryColor(const QString &cat) const
 
 bool KCalPrefs::hasCategoryColor(const QString &cat) const
 {
-    return (categoryColor(cat) != d->mDefaultCategoryColor);
+    return categoryColor(cat) != d->mDefaultCategoryColor;
 }
 
 void KCalPrefs::setDayBegins(const QDateTime &dateTime)
@@ -321,4 +314,3 @@ QDateTime KCalPrefs::dayBegins() const
 {
     return d->mDayBegins;
 }
-
